@@ -461,7 +461,7 @@ def _build_arg_parser() -> argparse.ArgumentParser:
         "--use-parentheses",
         dest="use_parentheses",
         action="store_true",
-        help="Use parenthesis for line continuation on length limit instead of slashes.",
+        help="Use parentheses for line continuation on length limit instead of slashes.",
     )
     parser.add_argument(
         "-V",
@@ -593,10 +593,10 @@ def _build_arg_parser() -> argparse.ArgumentParser:
         dest="float_to_top",
         action="store_true",
         help="Causes all non indented imports to float to the top of the file having its imports "
-        "sorted. *NOTE*: This is a **beta** feature. It currently doesn't work with cimports and "
-        "is gauranteed to run much slower and use much more memory than the default. Still it "
-        "can be a great shortcut for collecting imports every once in a while when you put them "
-        "in the middle of a file.",
+        "sorted. *NOTE*: This is an **experimental** feature. It currently doesn't work with "
+        "cimports and is guaranteed to run much slower and use much more memory than the default. "
+        "Still it can be a great shortcut for collecting imports every once in a while when you put"
+        " them in the middle of a file.",
     )
     # deprecated options
     parser.add_argument(
